==> servicecatalog-model-6.2.0-sources.jar: io/fabric8/servicecatalog/api/model/ServiceInstancePropertiesStateFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ServiceInstancePropertiesStateFluent<A extends ServiceInstancePropertiesStateFluent<A>> extends Fluent<A>{
  public String getClusterServicePlanExternalID();
  public A withClusterServicePlanExternalID(String clusterServicePlanExternalID);
  public Boolean hasClusterServicePlanExternalID();
  public String getClusterServicePlanExternalName();
  public A withClusterServicePlanExternalName(String clusterServicePlanExternalName);
  public Boolean hasClusterServicePlanExternalName();
  public String getParameterChecksum();
  public A withParameterChecksum(String parameterChecksum);
  public Boolean hasParameterChecksum();
  public A addToParameters(String key,Object value);
  public A addToParameters(Map<String,Object> map);
  public A removeFromParameters(String key);
  public A removeFromParameters(Map<String,Object> map);
  public Map<String,Object> getParameters();
  public <K,V>A withParameters(Map<String,Object> parameters);
  public Boolean hasParameters();
  public String getServicePlanExternalID();
  public A withServicePlanExternalID(String servicePlanExternalID);
  public Boolean hasServicePlanExternalID();
  public String getServicePlanExternalName();
  public A withServicePlanExternalName(String servicePlanExternalName);
  public Boolean hasServicePlanExternalName();
  
  /**
   * This method has been deprecated, please use method buildUserInfo instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserInfo getUserInfo();
  public UserInfo buildUserInfo();
  public A withUserInfo(UserInfo userInfo);
  public Boolean hasUserInfo();
  public ServiceInstancePropertiesStateFluent.UserInfoNested<A> withNewUserInfo();
  public ServiceInstancePropertiesStateFluent.UserInfoNested<A> withNewUserInfoLike(UserInfo item);
  public ServiceInstancePropertiesStateFluent.UserInfoNested<A> editUserInfo();
  public ServiceInstancePropertiesStateFluent.UserInfoNested<A> editOrNewUserInfo();
  public ServiceInstancePropertiesStateFluent.UserInfoNested<A> editOrNewUserInfoLike(UserInfo item);
  public interface UserInfoNested<N> extends Nested<N>,UserInfoFluent<ServiceInstancePropertiesStateFluent.UserInfoNested<N>>{
    public N and();
    public N endUserInfo();
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceInstancePropertiesStateFluent.java <==
package io.fabric8.servicecatalog.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ServiceInstancePropertiesStateFluent<A extends ServiceInstancePropertiesStateFluent<A>> extends Fluent<A>{
  public String getClusterServicePlanExternalID();
  public A withClusterServicePlanExternalID(String clusterServicePlanExternalID);
  public Boolean hasClusterServicePlanExternalID();
  public String getClusterServicePlanExternalName();
  public A withClusterServicePlanExternalName(String clusterServicePlanExternalName);
  public Boolean hasClusterServicePlanExternalName();
  public String getParameterChecksum();
  public A withParameterChecksum(String parameterChecksum);
  public Boolean hasParameterChecksum();
  public A addToParameters(String key,Object value);
  public A addToParameters(Map<String,Object> map);
  public A removeFromParameters(String key);
  public A removeFromParameters(Map<String,Object> map);
  public Map<String,Object> getParameters();
  public <K,V>A withParameters(Map<String,Object> parameters);
  public Boolean hasParameters();
  public String getServicePlanExternalID();
  public A withServicePlanExternalID(String servicePlanExternalID);
  public Boolean hasServicePlanExternalID();
  public String getServicePlanExternalName();
  public A withServicePlanExternalName(String servicePlanExternalName);
  public Boolean hasServicePlanExternalName();
  
  /**
   * This method has been deprecated, please use method buildUserInfo instead.
   * @return The buildable object.
   */
  @Deprecated
  public UserInfo getUserInfo();
  public UserInfo buildUserInfo();
  public A withUserInfo(UserInfo userInfo);
  public Boolean hasUserInfo();
  public ServiceInstancePropertiesStateFluent.UserInfoNested<A> withNewUserInfo();
  public ServiceInstancePropertiesStateFluent.UserInfoNested<A> withNewUserInfoLike(UserInfo item);
  public ServiceInstancePropertiesStateFluent.UserInfoNested<A> editUserInfo();
  public ServiceInstancePropertiesStateFluent.UserInfoNested<A> editOrNewUserInfo();
  public ServiceInstancePropertiesStateFluent.UserInfoNested<A> editOrNewUserInfoLike(UserInfo item);
  public interface UserInfoNested<N> extends Nested<N>,UserInfoFluent<ServiceInstancePropertiesStateFluent.UserInfoNested<N>>{
    public N and();
    public N endUserInfo();
    
  }
  
}
